@@ -1,17 +1,23 @@
-# Copyright (C) 2007, 2008, 2009  Andrey Golovizin
+# Copyright (c) 2007, 2008, 2009, 2010, 2011  Andrey Golovizin
 # 
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# Permission is hereby granted, free of charge, to any person obtaining
+# a copy of this software and associated documentation files (the
+# "Software"), to deal in the Software without restriction, including
+# without limitation the rights to use, copy, modify, merge, publish,
+# distribute, sublicense, and/or sell copies of the Software, and to
+# permit persons to whom the Software is furnished to do so, subject to
+# the following conditions:
 # 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# The above copyright notice and this permission notice shall be
+# included in all copies or substantial portions of the Software.
 # 
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 import re
 
@@ -57,6 +63,9 @@ class BibTeXString(object):
         self.is_closed = False
         self.contents = list(self.find_closing_brace(iter(chars)))
 
+    def __iter__(self):
+        return self.traverse()
+
     def find_closing_brace(self, chars):
         for char in chars:
             if char == '{':
@@ -77,9 +86,11 @@ class BibTeXString(object):
         for child in self.contents:
             if hasattr(child, 'traverse'):
                 if child.is_special_char():
-                    yield open(child)
+                    if open is not None:
+                        yield open(child)
                     yield f(child.inner_string(), child)
-                    yield close(child)
+                    if close is not None:
+                        yield close(child)
                 else:
                     for result in child.traverse(open, f, close):
                         yield result
@@ -116,6 +127,8 @@ def change_case(string, mode):
     And {\Now: booo!!!}
     >>> print change_case(r'And {\Now: {BOOO}!!!}', 'l')
     and {\Now: {booo}!!!}
+    >>> print change_case(r'{\TeX\ and databases\Dash\TeX DBI}', 't')
+    {\TeX\ and databases\Dash\TeX DBI}
     """
 
     def title(char, state):
@@ -127,17 +140,16 @@ def change_case(string, mode):
     lower = lambda char, state: char.lower()
     upper = lambda char, state: char.upper()
 
-    convert_level0 = {'l': lower, 'u': upper, 't': title}[mode]
-    convert_level1 = {'l': lower, 'u': upper, 't': lower}[mode]
+    convert = {'l': lower, 'u': upper, 't': title}[mode]
 
-    def convert_special_char(special_char):
+    def convert_special_char(special_char, state):
         # FIXME BibTeX treats some accented and foreign characterss specially
         def convert_words(words):
             for word in words:
                 if word.startswith('\\'):
                     yield word
                 else:
-                    yield convert_level1(word, 'normal')
+                    yield convert(word, state)
 
         return ' '.join(convert_words(special_char.split(' ')))
 
@@ -145,7 +157,7 @@ def change_case(string, mode):
         state = 'start'
         for char, brace_level in scan_bibtex_string(string):
             if brace_level == 0:
-                yield convert_level0(char, state)
+                yield convert(char, state)
                 if char == ':':
                     state = 'after colon'
                 elif char.isspace() and state == 'after colon':
@@ -154,10 +166,9 @@ def change_case(string, mode):
                     state = 'normal'
             else:
                 if brace_level == 1 and char.startswith('\\'):
-                    yield convert_special_char(char)
+                    yield convert_special_char(char, state)
                 else:
                     yield char
-                state = 'normal'
 
     return ''.join(change_case_iter(string, mode))
 
@@ -167,7 +178,7 @@ def bibtex_substring(string, start, length):
     Return a substring of the given length, starting from the given position.
 
     start and length are 1-based. If start is < 0, it is counted from the end
-    of the string.
+    of the string. If start is 0, an empty string is returned.
 
     >>> print bibtex_substring('abcdef', 1, 3)
     abc
@@ -175,6 +186,8 @@ def bibtex_substring(string, start, length):
     bcd
     >>> print bibtex_substring('abcdef', 2, 1000)
     bcdef
+    >>> print bibtex_substring('abcdef', 0, 1000)
+    <BLANKLINE>
     >>> print bibtex_substring('abcdef', -1, 1)
     f
     >>> print bibtex_substring('abcdef', -1, 2)
@@ -191,8 +204,8 @@ def bibtex_substring(string, start, length):
     elif start < 0:
         end0 = len(string) + start + 1
         start0 = end0 - length
-    else:
-        raise BibTeXError('start=0 passed to substring$')
+    else: # start == 0:
+        return u''
     return string[start0:end0]
 
 
@@ -338,6 +351,7 @@ def split_name_list(string):
     """
     return split_tex_string(string, ' and ')
 
+
 def split_tex_string(string, sep=None, strip=True, filter_empty=False):
     """Split a string using the given separator (regexp).
 
@@ -392,3 +406,31 @@ def split_tex_string(string, sep=None, strip=True, filter_empty=False):
     if filter_empty:
         result = [part for part in result if part]
     return result
+
+
+def bibtex_first_letter(string):
+    """ Return the first letter or special character of the string.
+
+    >>> print bibtex_first_letter('Andrew Blake')
+    A
+    >>> print bibtex_first_letter('{Andrew} Blake')
+    A
+    >>> print bibtex_first_letter('1Andrew')
+    A
+    >>> print bibtex_first_letter('{\TeX} markup')
+    {\TeX}
+    >>> print bibtex_first_letter('')
+    <BLANKLINE>
+    >>> print bibtex_first_letter('123 123 123 {}')
+    <BLANKLINE>
+    >>> print bibtex_first_letter('\LaTeX Project Team')
+    L
+
+    """
+
+    for char in BibTeXString(string):
+        if char.startswith('\\') and char != '\\':
+            return u'{{{0}}}'.format(char)
+        elif char.isalpha():
+            return char
+    return ''
