@@ -1,17 +1,23 @@
-# Copyright (C) 2006, 2007, 2008, 2009  Andrey Golovizin
+# Copyright (c) 2006, 2007, 2008, 2009, 2010, 2011  Andrey Golovizin
 # 
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# Permission is hereby granted, free of charge, to any person obtaining
+# a copy of this software and associated documentation files (the
+# "Software"), to deal in the Software without restriction, including
+# without limitation the rights to use, copy, modify, merge, publish,
+# distribute, sublicense, and/or sell copies of the Software, and to
+# permit persons to whom the Software is furnished to do so, subject to
+# the following conditions:
 # 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# The above copyright notice and this permission notice shall be
+# included in all copies or substantial portions of the Software.
 # 
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 """pybtex' core datatypes
 """
@@ -21,7 +27,7 @@ import re
 from pybtex.exceptions import PybtexError
 from pybtex.bibtex.utils import split_tex_string
 
-class FormattedEntry:
+class FormattedEntry(object):
     """Formatted bibliography entry. Consists of
     - key (which is used for sorting);
     - label (which appears in the resulting bibliography)
@@ -66,20 +72,29 @@ class Entry(object):
         # for BibTeX interpreter
         self.vars = {}
 
-    def get_crossref(self):
-        return self.collection.entries[self.fields['crossref']]
-
     def __eq__(self, other):
         if not isinstance(other, Entry):
             return super(Entry, self) == other
         return (
-                self.fields == other.fields
+                self.type == other.type
+                and self.fields == other.fields
                 and self.persons == other.persons
         )
 
+    def __repr__(self):
+        return 'Entry({type_}, fields={fields}, persons={persons})'.format(
+            type_=repr(self.type),
+            fields=repr(self.fields),
+            persons=repr(self.persons),
+        )
+
+    def get_crossref(self):
+        return self.collection.entries[self.fields['crossref']]
+
     def add_person(self, person, role):
         self.persons.setdefault(role, []).append(person)
 
+
 class Person(object):
     """Represents a person (usually human).
 
@@ -117,10 +132,14 @@ class Person(object):
     >>> p = Person('abc')
     >>> print p.first(), p.middle(), p.prelast(), p.last(), p.lineage()
     [] [] [] ['abc'] []
+    >>> p = Person('Viktorov, Michail~Markovitch')
+    >>> print p.first(), p.middle(), p.prelast(), p.last(), p.lineage()
+    ['Michail'] ['Markovitch'] [] ['Viktorov'] []
     """
     valid_roles = ['author', 'editor'] 
     style1_re = re.compile('^(.+),\s*(.+)$')
     style2_re = re.compile('^(.+),\s*(.+),\s*(.+)$')
+
     def __init__(self, string="", first="", middle="", prelast="", last="", lineage=""):
         self._first = []
         self._middle = []
@@ -210,6 +229,9 @@ class Person(object):
         first = ' '.join(self._first + self._middle)
         return ', '.join(part for part in (von_last, jr, first) if part)
 
+    def __repr__(self):
+        return 'Person({0})'.format(repr(unicode(self)))
+
     def get_part_as_text(self, type):
         names = getattr(self, '_' + type)
         return ' '.join(names)
