@@ -1,24 +1,28 @@
 #!/usr/bin/env python
 
-# Copyright (C) 2006, 2007, 2008, 2009  Andrey Golovizin
+# Copyright (c) 2006, 2007, 2008, 2009, 2010, 2011  Andrey Golovizin
 # 
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# Permission is hereby granted, free of charge, to any person obtaining
+# a copy of this software and associated documentation files (the
+# "Software"), to deal in the Software without restriction, including
+# without limitation the rights to use, copy, modify, merge, publish,
+# distribute, sublicense, and/or sell copies of the Software, and to
+# permit persons to whom the Software is furnished to do so, subject to
+# the following conditions:
 # 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# The above copyright notice and this permission notice shall be
+# included in all copies or substantial portions of the Software.
 # 
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-from optparse import make_option
-
-from pybtex.cmdline import CommandLine
+from pybtex.cmdline import CommandLine, make_option
 
 class PybtexConvertCommandLine(CommandLine):
     prog = 'pybtex-convert'
@@ -36,12 +40,14 @@ pybtex-convert converts bibliography database files between supported formats
     options = (
         (None, (
             make_option(
-                '-f', '--from', action='store', type='string', dest='from_format',
-                help='input format', metavar='FORMAT',
+                '-f', '--from', dest='from_format',
+                help='input format (%plugin_choices)', metavar='FORMAT',
+                type='load_plugin', plugin_group='pybtex.database.input',
             ),
             make_option(
-                '-t', '--to', action='store', type='string', dest='to_format',
-                help='output format', metavar='FORMAT',
+                '-t', '--to', dest='to_format',
+                help='output format (%plugin_choices)', metavar='FORMAT',
+                type='load_plugin', plugin_group='pybtex.database.output',
             ),
             make_option(
                 '--allow-keyless-bibtex-entries',
