@@ -1,19 +1,63 @@
-# Copyright (C) 2006, 2007, 2008, 2009  Andrey Golovizin
+# Copyright (c) 2006, 2007, 2008, 2009, 2010, 2011  Andrey Golovizin
 # 
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# Permission is hereby granted, free of charge, to any person obtaining
+# a copy of this software and associated documentation files (the
+# "Software"), to deal in the Software without restriction, including
+# without limitation the rights to use, copy, modify, merge, publish,
+# distribute, sublicense, and/or sell copies of the Software, and to
+# permit persons to whom the Software is furnished to do so, subject to
+# the following conditions:
 # 
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# The above copyright notice and this permission notice shall be
+# included in all copies or substantial portions of the Software.
 # 
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-"""BibTeX parser"""
+"""BibTeX parser
+
+>>> from io import StringIO
+>>> parser = Parser()
+>>> bib_data = parser.parse_stream(StringIO(u'''
+... @String{SCI = "Science"}
+... 
+... @String{JFernandez = "Fernandez, Julio M."}
+... @String{HGaub = "Gaub, Hermann E."}
+... @String{MGautel = "Gautel, Mathias"}
+... @String{FOesterhelt = "Oesterhelt, Filipp"}
+... @String{MRief = "Rief, Matthias"}
+... 
+... @Article{rief97b,
+...   author =       MRief #" and "# MGautel #" and "# FOesterhelt
+...                  #" and "# JFernandez #" and "# HGaub,
+...   title =        "Reversible Unfolding of Individual Titin
+...                  Immunoglobulin Domains by {AFM}",
+...   journal =      SCI,
+...   volume =       276,
+...   number =       5315,
+...   pages =        "1109--1112",
+...   year =         1997,
+...   doi =          "10.1126/science.276.5315.1109",
+...   URL =          "http://www.sciencemag.org/cgi/content/abstract/276/5315/1109",
+...   eprint =       "http://www.sciencemag.org/cgi/reprint/276/5315/1109.pdf",
+... }
+... '''))
+>>> rief97b = parser.data.entries['rief97b']
+>>> authors = rief97b.persons['author']
+>>> for author in authors:
+...     print unicode(author)
+Rief, Matthias
+Gautel, Mathias
+Oesterhelt, Filipp
+Fernandez, Julio M.
+Gaub, Hermann E.
+
+"""
 
 from pyparsing import (
         Word, Literal, CaselessLiteral, CharsNotIn,
@@ -24,7 +68,7 @@ from pyparsing import (
 )
 import pybtex.io
 from pybtex.core import Entry, Person
-from pybtex.database.input import ParserBase
+from pybtex.database.input import BaseParser
 from pybtex.bibtex.utils import split_name_list
 from pybtex.exceptions import PybtexError
 from pybtex import textutils
@@ -44,20 +88,20 @@ month_names = {
     'dec': 'December'
 }
 
-file_extension = 'bib'
-
 
 def normalize_whitespace(s, loc, toks):
     return [textutils.normalize_whitespace(tok) for tok in toks]
 
 
-class Parser(ParserBase):
+class Parser(BaseParser):
+    name = 'bibtex'
+    suffixes = '.bib',
     unicode_io = True
 
     def __init__(self, encoding=None, macros=month_names, person_fields=Person.valid_roles, **kwargs):
-        ParserBase.__init__(self, encoding)
+        BaseParser.__init__(self, encoding)
 
-        self.default_macros = dict(macros)
+        self.macros = dict(macros)
         self.person_fields = person_fields
 
         lbrace = Suppress('{')
@@ -73,12 +117,13 @@ class Parser(ParserBase):
         innerBracedString << Combine(Literal('{') + ZeroOrMore(CharsNotIn('{}') | innerBracedString) + Literal('}'))
         quotedString = Combine(Suppress('"') + ZeroOrMore(CharsNotIn('"{') | innerBracedString) + Suppress('"'))
         bracedString = Combine(lbrace + ZeroOrMore(CharsNotIn('{}') | innerBracedString) + rbrace)
-        bibTeXString = (quotedString | bracedString).setParseAction(normalize_whitespace)
+        bibTeXString = (quotedString | bracedString)
 
         name_chars = alphanums + '!$&*+-./:;<>?[\\]^_`|~\x7f'
-        macro_substitution = Word(name_chars).setParseAction(self.substitute_macro)
+        macro_substitution = Word(name_chars).setParseAction(lambda toks: self.substitute_macro(toks))
         name = Word(name_chars).setParseAction(downcaseTokens)
         value = Combine(delimitedList(bibTeXString | Word(nums) | macro_substitution, delim='#'), adjacent=False)
+        value.setParseAction(normalize_whitespace)
 
         #fields
         field = Group(name + Suppress('=') + value)
@@ -87,7 +132,7 @@ class Parser(ParserBase):
         #String (aka macro)
         string_body = bibtexGroup(fields)
         string = at + CaselessLiteral('STRING').suppress() + string_body
-        string.setParseAction(self.process_macro)
+        string.setParseAction(lambda toks: self.process_macro(toks))
 
         #preamble
         preamble_body = bibtexGroup(value)
@@ -127,20 +172,19 @@ class Parser(ParserBase):
 #        return (key, entry)
         self.data.add_entry(key, entry)
 
-    def substitute_macro(self, s, loc, toks):
+    def substitute_macro(self, toks):
         key = toks[0].lower()
         try:
             return self.macros[key]
         except KeyError:
             raise PybtexError('undefined macro %s' % key)
 
-    def process_macro(self, s, loc, toks):
+    def process_macro(self, toks):
         self.macros[toks[0][0].lower()] = toks[0][1]
 
     def parse_stream(self, stream):
         self.unnamed_entry_counter = 1
 
-        self.macros = dict(self.default_macros)
         try:
 #            entries = dict(entry[0][0] for entry in self.BibTeX_entry.scanString(s))
             self.BibTeX_entry.searchString(stream.read())
@@ -149,3 +193,4 @@ class Parser(ParserBase):
             print e
             import sys
             sys.exit(1)
+        return self.data
